pub struct KnownEvents {
pub storage: Arc<EventStorage<RedbDatabase>>,
pub oobi_manager: OobiManager,
pub partially_witnessed_escrow: Arc<PartiallyWitnessedEscrow<RedbDatabase>>,
pub tel: Arc<Tel<RedbTelDatabase, RedbDatabase>>,
/* private fields */
}Fields
storage: Arc<EventStorage<RedbDatabase>>oobi_manager: OobiManagerpartially_witnessed_escrow: Arc<PartiallyWitnessedEscrow<RedbDatabase>>tel: Arc<Tel<RedbTelDatabase, RedbDatabase>>Implementations
Sourceimpl KnownEvents
impl KnownEvents
pub fn verify( &self, data: &[u8], signature: &Signature, ) -> Result<(), VerificationError>
pub fn verify_from_cesr(&self, stream: &[u8]) -> Result<(), ControllerError>
Sourceimpl KnownEvents
impl KnownEvents
pub fn new( db_path: PathBuf, escrow_config: EscrowConfig, ) -> Result<Self, ControllerError>
pub fn save(&self, message: &Message) -> Result<(), MechanicsError>
pub fn save_oobi(&self, oobi: &SignedReply) -> Result<(), MechanicsError>
pub fn current_public_keys( &self, id: &IdentifierPrefix, ) -> Result<Vec<BasicPrefix>, MechanicsError>
pub fn next_keys_hashes( &self, id: &IdentifierPrefix, ) -> Result<Vec<SelfAddressingIdentifier>, MechanicsError>
pub fn get_watchers( &self, id: &IdentifierPrefix, ) -> Result<Vec<IdentifierPrefix>, ControllerError>
pub fn process(&self, msg: &Message) -> Result<Option<Vec<Message>>, Error>
Sourcepub fn process_stream(&self, stream: &[u8]) -> Result<(), ControllerError>
pub fn process_stream(&self, stream: &[u8]) -> Result<(), ControllerError>
Parse and process events stream
Sourcepub fn get_loc_schemas(
&self,
id: &IdentifierPrefix,
) -> Result<Vec<LocationScheme>, OobiRetrieveError>
pub fn get_loc_schemas( &self, id: &IdentifierPrefix, ) -> Result<Vec<LocationScheme>, OobiRetrieveError>
Returns identifier contact information.
pub fn find_location( &self, id: &IdentifierPrefix, scheme: Scheme, ) -> Result<LocationScheme, OobiRetrieveError>
pub fn find_receipt( &self, id: &IdentifierPrefix, sn: u64, digest: &SelfAddressingIdentifier, ) -> Result<Option<SignedNontransferableReceipt>, Error>
pub fn find_kel_with_receipts( &self, id: &IdentifierPrefix, ) -> Option<Vec<Notice>>
pub fn find_kel(&self, id: &IdentifierPrefix) -> Option<String>
pub fn incept( &self, public_keys: Vec<BasicPrefix>, next_pub_keys: Vec<BasicPrefix>, witnesses: Vec<LocationScheme>, witness_threshold: u64, ) -> Result<String, MechanicsError>
Sourcepub fn finalize_inception(
&self,
event: &[u8],
sig: &SelfSigningPrefix,
) -> Result<IdentifierPrefix, MechanicsError>
pub fn finalize_inception( &self, event: &[u8], sig: &SelfSigningPrefix, ) -> Result<IdentifierPrefix, MechanicsError>
Verifies event signature and adds it to kel.
Returns new established identifier prefix.
Meant to be used for identifiers with one key pair.
Must call IdentifierController::notify_witnesses after calling this function.
Sourcepub fn anchor_with_seal(
&self,
id: &IdentifierPrefix,
payload: &[Seal],
) -> Result<KeriEvent<KeyEvent>, MechanicsError>
pub fn anchor_with_seal( &self, id: &IdentifierPrefix, payload: &[Seal], ) -> Result<KeriEvent<KeyEvent>, MechanicsError>
Generate and return rotation event for given identifier data Generate and return interaction event for given identifier data Generate and return interaction event for given identifier data
pub fn get_current_witness_list( &self, id: &IdentifierPrefix, ) -> Result<Vec<BasicPrefix>, MechanicsError>
Sourcepub fn finalize_key_event(
&self,
event: &KeriEvent<KeyEvent>,
sig: &SelfSigningPrefix,
own_index: usize,
) -> Result<(), MechanicsError>
pub fn finalize_key_event( &self, event: &KeriEvent<KeyEvent>, sig: &SelfSigningPrefix, own_index: usize, ) -> Result<(), MechanicsError>
Adds signature to event and processes it.
Should call IdentifierController::notify_witnesses after calling this function.
pub fn get_state_at_event( &self, event_message: &KeriEvent<KeyEvent>, ) -> Result<IdentifierState, MechanicsError>
pub fn find_witnesses_at_event( &self, event_message: &KeriEvent<KeyEvent>, ) -> Result<Vec<BasicPrefix>, MechanicsError>
pub fn finalize_add_role( &self, signer_prefix: &IdentifierPrefix, event: ReplyEvent, sig: Vec<SelfSigningPrefix>, ) -> Result<(IdentifierPrefix, Vec<Message>), MechanicsError>
pub fn get_state( &self, id: &IdentifierPrefix, ) -> Result<IdentifierState, MechanicsError>