MailboxReminder

Struct MailboxReminder 

pub struct MailboxReminder {
    pub receipt: usize,
    pub multisig: usize,
    pub delegate: usize,
}
Struct for tracking what was the last indexes of processed mailbox messages. Events in mailbox aren’t removed after getting them, so it prevents processing the same event multiple times.

Fields

receipt: usizemultisig: usizedelegate: usize

Implementations