pub struct MailboxReminder {
pub receipt: usize,
pub multisig: usize,
pub delegate: usize,
}Expand description
Struct for tracking what was the last indexes of processed mailbox messages. Events in mailbox aren’t removed after getting them, so it prevents processing the same event multiple times.
Fields
receipt: usizemultisig: usizedelegate: usizeImplementations
Sourceimpl MailboxReminder
impl MailboxReminder
pub fn to_query_topics(&self) -> QueryTopics